@@ -55,20 +55,18 @@ def sanitize(input: str) -> str:
 
 def sql_initialize():
     download_history = "download_history_size_based.sqlite"
-    if not os.path.isfile(download_history):
-        conn = sqlite3.connect(download_history)
-        curr = conn.cursor()
-        create_table_query = """CREATE TABLE downloads (
-                                    filename TEXT,
-                                    size INTEGER NOT NULL,
-                                    completed INTEGER NOT NULL,
-                                    PRIMARY KEY (filename, size)
-                                );"""
-        curr.execute(create_table_query)
-        conn.commit()
-    else:
-        conn = sqlite3.connect(download_history)
-        curr = conn.cursor()
+
+    conn = sqlite3.connect(download_history)
+    curr = conn.cursor()
+    create_table_query = """CREATE TABLE IF NOT EXISTS downloads (
+                                filename TEXT,
+                                size INTEGER NOT NULL,
+                                completed INTEGER NOT NULL,
+                                PRIMARY KEY (filename, size)
+                            );"""
+    curr.execute(create_table_query)
+
+    conn.commit()
     return conn, curr
 
 
@@ -83,12 +81,10 @@ async def sql_check_existing(cursor: sqlite3.Cursor, url, size):
 
 async def sql_insert_file(connection: sqlite3.Connection, cursor: sqlite3.Cursor, filename, size, completed):
     cursor.execute("""INSERT OR IGNORE INTO downloads VALUES ('%s', %d, %d)""" % (filename, size, completed))
-    connection.commit()
 
 
 async def sql_update_file(connection: sqlite3.Connection, cursor: sqlite3.Cursor, filename, size, completed):
     cursor.execute("""INSERT OR REPLACE INTO downloads VALUES ('%s', %d, %d)""" % (filename, size, completed))
-    connection.commit()
 
 
 def log(text, style=Fore.WHITE) -> None:
@@ -106,6 +102,23 @@ def make_title_safe(title: str):
     return title
 
 
+def purge_dir(dir, in_place=True):
+
+    deleted = []
+    dir_tree = list(os.walk(dir, topdown=False))
+
+    for tree_element in dir_tree:
+        sub_dir = tree_element[0]
+        is_empty = not len(os.listdir(sub_dir))
+        if is_empty:
+            deleted.append(sub_dir)
+
+    if in_place:
+        list(map(os.rmdir, deleted))
+
+    return deleted
+
+
 def regex_links(urls) -> list:
     all_links = [x.group().replace(".md.", ".") for x in
                  re.finditer(r"(?:http.*?)(?=('|$|\n|\r\n|\r|\s|\"|\[/URL]))", urls)]
